summaryrefslogtreecommitdiffstats
path: root/libkonq/konq_operations.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkonq/konq_operations.h')
-rw-r--r--libkonq/konq_operations.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/libkonq/konq_operations.h b/libkonq/konq_operations.h
index 82d021c55..42a00e814 100644
--- a/libkonq/konq_operations.h
+++ b/libkonq/konq_operations.h
@@ -22,8 +22,8 @@
#include <kurl.h>
#include <libkonq_export.h>
-#include <qobject.h>
-#include <qevent.h>
+#include <tqobject.h>
+#include <tqevent.h>
namespace KIO { class Job; class CopyInfo; }
class QWidget;
@@ -38,14 +38,14 @@ class LIBKONQ_EXPORT KonqOperations : public QObject
{
Q_OBJECT
protected:
- KonqOperations( QWidget * parent );
+ KonqOperations( TQWidget * parent );
virtual ~KonqOperations();
public:
/**
* Pop up properties dialog for mimetype @p mimeType.
*/
- static void editMimeType( const QString & mimeType );
+ static void editMimeType( const TQString & mimeType );
enum { TRASH, DEL, SHRED, COPY, MOVE, LINK, EMPTYTRASH, STAT, MKDIR, RESTORE, UNKNOWN };
/**
@@ -55,7 +55,7 @@ public:
* @param method should be TRASH, DEL or SHRED
* @param selectedURLs the URLs to be deleted
*/
- static void del( QWidget * parent, int method, const KURL::List & selectedURLs );
+ static void del( TQWidget * parent, int method, const KURL::List & selectedURLs );
/**
* Copy the @p selectedURLs to the destination @p destURL.
@@ -67,7 +67,7 @@ public:
*
* @todo document restrictions on the kind of destination
*/
- static void copy( QWidget * parent, int method, const KURL::List & selectedURLs, const KURL& destURL );
+ static void copy( TQWidget * parent, int method, const KURL::List & selectedURLs, const KURL& destURL );
/**
* Drop
* @param destItem destination KFileItem for the drop (background or item)
@@ -77,13 +77,13 @@ public:
*
* If destItem is 0L, doDrop will stat the URL to determine it.
*/
- static void doDrop( const KFileItem * destItem, const KURL & destURL, QDropEvent * ev, QWidget * parent );
+ static void doDrop( const KFileItem * destItem, const KURL & destURL, TQDropEvent * ev, TQWidget * parent );
/**
* Paste the clipboard contents
*/
- static void doPaste( QWidget * parent, const KURL & destURL, const QPoint &pos );
- static void doPaste( QWidget * parent, const KURL & destURL );
+ static void doPaste( TQWidget * parent, const KURL & destURL, const TQPoint &pos );
+ static void doPaste( TQWidget * parent, const KURL & destURL );
static void emptyTrash();
static void restoreTrashedItems( const KURL::List& urls );
@@ -91,7 +91,7 @@ public:
/**
* Create a directory
*/
- static void mkdir( QWidget *parent, const KURL & url );
+ static void mkdir( TQWidget *parent, const KURL & url );
/**
* Get info about a given URL, and when that's done (it's asynchronous!),
@@ -99,7 +99,7 @@ public:
* The KFileItem will be deleted by statURL after calling the slot. Make a copy
* if you need one !
*/
- static void statURL( const KURL & url, const QObject *receiver, const char *member );
+ static void statURL( const KURL & url, const TQObject *receiver, const char *member );
/**
* Do a renaming.
@@ -107,7 +107,7 @@ public:
* @param oldurl the current url of the file to be renamed
* @param name the new name for the file. Shouldn't include '/'.
*/
- static void rename( QWidget * parent, const KURL & oldurl, const QString & name );
+ static void rename( TQWidget * parent, const KURL & oldurl, const TQString & name );
/**
* Do a renaming.
@@ -117,14 +117,14 @@ public:
* Use this version if the other one wouldn't work :) (e.g. because name could
* be a relative path, including a '/').
*/
- static void rename( QWidget * parent, const KURL & oldurl, const KURL & newurl );
+ static void rename( TQWidget * parent, const KURL & oldurl, const KURL & newurl );
/**
* Ask for the name of a new directory and create it.
* @param parent the parent widget
* @param baseURL the directory to create the new directory in
*/
- static void newDir( QWidget * parent, const KURL & baseURL );
+ static void newDir( TQWidget * parent, const KURL & baseURL );
enum ConfirmationType { DEFAULT_CONFIRMATION, SKIP_CONFIRMATION, FORCE_CONFIRMATION };
/**
@@ -135,49 +135,49 @@ public:
* @param widget parent widget for message boxes
* @return true if confirmed
*/
- static bool askDeleteConfirmation( const KURL::List & selectedURLs, int method, ConfirmationType confirmation, QWidget* widget );
+ static bool askDeleteConfirmation( const KURL::List & selectedURLs, int method, ConfirmationType confirmation, TQWidget* widget );
signals:
void statFinished( const KFileItem * item );
- void aboutToCreate(const QPoint &pos, const QValueList<KIO::CopyInfo> &files);
+ void aboutToCreate(const TQPoint &pos, const TQValueList<KIO::CopyInfo> &files);
protected:
void _del( int method, const KURL::List & selectedURLs, ConfirmationType confirmation );
void _restoreTrashedItems( const KURL::List& urls );
- void _statURL( const KURL & url, const QObject *receiver, const char *member );
+ void _statURL( const KURL & url, const TQObject *receiver, const char *member );
// internal, for COPY/MOVE/LINK/MKDIR
void setOperation( KIO::Job * job, int method, const KURL::List & src, const KURL & dest );
struct DropInfo
{
- DropInfo( uint k, KURL::List & l, const QMap<QString,QString> &m,
- int x, int y, QDropEvent::Action a ) :
+ DropInfo( uint k, KURL::List & l, const TQMap<TQString,TQString> &m,
+ int x, int y, TQDropEvent::Action a ) :
keybstate(k), lst(l), metaData(m), mousePos(x,y), action(a) {}
uint keybstate;
KURL::List lst;
- QMap<QString,QString> metaData;
- QPoint mousePos;
- QDropEvent::Action action;
+ TQMap<TQString,TQString> metaData;
+ TQPoint mousePos;
+ TQDropEvent::Action action;
};
// internal, for doDrop
void setDropInfo( DropInfo * info ) { m_info = info; }
- struct KIOPasteInfo // KDE4: remove and use DropInfo instead or a QPoint member
+ struct KIOPasteInfo // KDE4: remove and use DropInfo instead or a TQPoint member
{
- QByteArray data; // unused
+ TQByteArray data; // unused
KURL destURL; // unused
- QPoint mousePos;
- QString dialogText; // unused
+ TQPoint mousePos;
+ TQString dialogText; // unused
};
void setPasteInfo( KIOPasteInfo * info ) { m_pasteInfo = info; }
private:
- QWidget* parentWidget() const;
+ TQWidget* parentWidget() const;
protected slots:
- void slotAboutToCreate(KIO::Job *job, const QValueList<KIO::CopyInfo> &files);
+ void slotAboutToCreate(KIO::Job *job, const TQValueList<KIO::CopyInfo> &files);
void slotResult( KIO::Job * job );
void slotStatResult( KIO::Job * job );
void asyncDrop( const KFileItem * item );